yandexcloud
    * ``auth_token`` Specify the iam token (https://cloud.yandex.com/en/docs/dns/api-ref/authentication)

    * ``dns_zone_id`` Specify the dns zone id (can be obtained from web interface)

    * ``cloud_id`` Specify the cloud id (visible in the cloud selector in the web interface), might be needed if dns zone id is not set

    * ``folder_id`` Specify the folder id (https://cloud.yandex.com/en/docs/resource-manager/operations/folder/get-id) might be needed if dns zone id is not set
